@@ -2,7 +2,7 @@
  * pydevice.h
  * pyparted type objects for pydevice.c
  *
- * Copyright (C) 2007, 2008, 2009  Red Hat, Inc.
+ * Copyright (C) 2007-2013 Red Hat, Inc.
  *
  * This copyrighted material is made available to anyone wishing to use,
  * modify, copy, or redistribute it subject to the terms and conditions of
@@ -18,13 +18,14 @@
  * License and may only be used or replicated with the express permission of
  * Red Hat, Inc.
  *
- * Red Hat Author(s): David Cantrell <dcantrell@redhat.com>
- *                    Chris Lumens <clumens@redhat.com>
+ * Author(s): David Cantrell <dcantrell@redhat.com>
+ *            Chris Lumens <clumens@redhat.com>
+ *            Alex Skinner <alex@lx.lc>
  */
 
 #ifndef TYPEOBJECTS_PYDEVICE_H_INCLUDED
 #define TYPEOBJECTS_PYDEVICE_H_INCLUDED
-
+#define PyGC_HEAD_SIZE 0
 #include <Python.h>
 #include <structmember.h>
 
@@ -51,14 +52,13 @@ static PyGetSetDef _ped_CHSGeometry_getset[] = {
 };
 
 PyTypeObject _ped_CHSGeometry_Type_obj = {
-    PyObject_HEAD_INIT(&PyType_Type)
+    PyVarObject_HEAD_INIT(&PyType_Type,0)
     .tp_name = "_ped.CHSGeometry",
     .tp_basicsize = sizeof(_ped_CHSGeometry),
  /* .tp_itemsize = XXX */
     .tp_dealloc = (destructor) _ped_CHSGeometry_dealloc,
  /* .tp_getattr = XXX */
  /* .tp_setattr = XXX */
-    .tp_compare = (cmpfunc) _ped_CHSGeometry_compare,
  /* .tp_repr = XXX */
  /* .tp_as_number = XXX */
  /* .tp_as_sequence = XXX */
@@ -69,8 +69,7 @@ PyTypeObject _ped_CHSGeometry_Type_obj = {
     .tp_getattro = PyObject_GenericGetAttr,
     .tp_setattro = PyObject_GenericSetAttr,
  /* .tp_as_buffer = XXX */
-    .tp_flags = Py_TPFLAGS_HAVE_CLASS | Py_TPFLAGS_BASETYPE |
-                Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_RICHCOMPARE,
+    .tp_flags = TP_FLAGS,
     .tp_doc = _ped_CHSGeometry_doc,
     .tp_traverse = (traverseproc) _ped_CHSGeometry_traverse,
     .tp_clear = (inquiry) _ped_CHSGeometry_clear,
@@ -159,17 +158,6 @@ static PyMethodDef _ped_Device_methods[] = {
     {"clobber", (PyCFunction) py_ped_disk_clobber, METH_VARARGS,
                 disk_clobber_doc},
 
-    /*
-     * These functions are in pyfilesys.c, but they work best
-     * as methods on a _ped.Device
-     */
-    {"get_create_constraint", (PyCFunction)
-                              py_ped_file_system_get_create_constraint,
-                              METH_VARARGS, file_system_get_create_constraint_doc},
-    {"get_copy_constraint", (PyCFunction)
-                            py_ped_file_system_get_copy_constraint,
-                            METH_VARARGS, file_system_get_copy_constraint_doc},
-
     /*
      * These functions are in pyunit.c, but they work best as methods
      * on a _ped.Device
@@ -225,14 +213,13 @@ static PyGetSetDef _ped_Device_getset[] = {
 };
 
 PyTypeObject _ped_Device_Type_obj = {
-    PyObject_HEAD_INIT(&PyType_Type)
+    PyVarObject_HEAD_INIT(&PyType_Type,0)
     .tp_name = "_ped.Device",
     .tp_basicsize = PyGC_HEAD_SIZE + sizeof(_ped_Device),
     .tp_itemsize = 0,
     .tp_dealloc = (destructor) _ped_Device_dealloc,
  /* .tp_getattr = XXX */
  /* .tp_setattr = XXX */
-    .tp_compare = (cmpfunc) _ped_Device_compare,
  /* .tp_repr = XXX */
  /* .tp_as_number = XXX */
  /* .tp_as_sequence = XXX */
@@ -243,8 +230,7 @@ PyTypeObject _ped_Device_Type_obj = {
     .tp_getattro = PyObject_GenericGetAttr,
     .tp_setattro = PyObject_GenericSetAttr,
  /* .tp_as_buffer = XXX */
-    .tp_flags = Py_TPFLAGS_HAVE_CLASS | Py_TPFLAGS_BASETYPE |
-                Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_RICHCOMPARE,
+    .tp_flags = TP_FLAGS,
     .tp_doc = _ped_Device_doc,
     .tp_traverse = (traverseproc) _ped_Device_traverse,
     .tp_clear = (inquiry) _ped_Device_clear,
