@@ -66,9 +66,6 @@ class Device(object):
         if not isinstance(self, other.__class__):
             return True
 
-        if getattr(other, "__hash__", None):
-            return hash(self) != hash(other)
-
         return self.model != other.model or self.path != other.path or self.type != other.type or self.length != other.length
 
     def __getCHS(self, geometry):
@@ -186,22 +183,6 @@ class Device(object):
               "ped": self.__device})
         return s
 
-    @property
-    def _hashstr(self):
-        s = ("  model: %(model)s  path: %(path)s  type: %(type)s\n"
-             "  sectorSize: %(sectorSize)s  physicalSectorSize:  %(physSectorSize)s\n"
-             "  length: %(length)s\n"
-             "  hardwareGeometry: %(hardwareGeom)s  biosGeometry: %(biosGeom)s\n"
-             "  PedDevice: %(ped)r" %
-             {"model": self.model, "path": self.path, "type": self.type,
-              "sectorSize": self.sectorSize, "physSectorSize": self.physicalSectorSize,
-              "length": self.length, "hardwareGeom": self.hardwareGeometry,
-              "biosGeom": self.biosGeometry, "ped": self.__device})
-        return s
-
-    def __hash__(self):
-        return hash(self._hashstr)
-
     @localeC
     def clobber(self):
         """Remove all identifying signatures of the partition table."""
