@@ -75,9 +75,6 @@ class Partition(object):
         if not isinstance(self, other.__class__):
             return True
 
-        if getattr(other, "__hash__", None):
-            return hash(self) != hash(other)
-
         return self.path != other.path or self.type != other.type or self.geometry != other.geometry or self.fileSystem != other.fileSystem
 
     def __str__(self):
@@ -97,25 +94,6 @@ class Partition(object):
               "busy": self.busy, "ped": self.__partition})
         return s
 
-    @property
-    def _hash_str(self):
-        try:
-            name = self.name
-        except parted.PartitionException:
-            name = None
-
-        s = ("  disk: %(disk)r\n"
-             "  number: %(number)s  path: %(path)s  type: %(type)s\n"
-             "  name: %(name)s\n"
-             "  geometry: %(geometry)r  PedPartition: %(ped)r" %
-             {"disk": self.disk, "number": self.number, "path": self.path,
-              "type": self.type, "name": name, "geometry": self.geometry,
-              "ped": self.__partition})
-        return s
-
-    def __hash__(self):
-        return hash(self._hash_str)
-
     def __writeOnly(self, prop):
         raise parted.WriteOnlyProperty(prop)
 
