@@ -1,7 +1,7 @@
 /*
  * pyconstraint.c
  *
- * Copyright (C) 2007, 2008, 2009  Red Hat, Inc.
+ * Copyright (C) 2007-2013  Red Hat, Inc.
  *
  * This copyrighted material is made available to anyone wishing to use,
  * modify, copy, or redistribute it subject to the terms and conditions of
@@ -17,8 +17,9 @@
  * License and may only be used or replicated with the express permission of
  * Red Hat, Inc.
  *
- * Red Hat Author(s): David Cantrell <dcantrell@redhat.com>
- *                    Chris Lumens <clumens@redhat.com>
+ * Author(s): David Cantrell <dcantrell@redhat.com>
+ *            Chris Lumens <clumens@redhat.com>
+ *            Alex Skinner <alex@lx.lc>
  */
 
 #include <Python.h>
@@ -77,18 +78,11 @@ int _ped_Constraint_compare(_ped_Constraint *self, PyObject *obj) {
 }
 
 PyObject *_ped_Constraint_richcompare(_ped_Constraint *a, PyObject *b, int op) {
-    if (op == Py_EQ) {
-        if (!(_ped_Constraint_Type_obj.tp_compare((PyObject *) a, b))) {
-            Py_RETURN_TRUE;
-        } else {
-            Py_RETURN_FALSE;
-        }
-    } else if (op == Py_NE) {
-        if (_ped_Constraint_Type_obj.tp_compare((PyObject *) a, b)) {
-            Py_RETURN_TRUE;
-        } else {
-            Py_RETURN_FALSE;
-        }
+    if (op == Py_EQ || op == Py_NE) {
+        int rv = _ped_Constraint_compare(a, b);
+        if (PyErr_Occurred())
+            return NULL;
+        return PyBool_FromLong(op == Py_EQ ? rv == 0 : rv != 0);
     } else if ((op == Py_LT) || (op == Py_LE) ||
                (op == Py_GT) || (op == Py_GE)) {
         PyErr_SetString(PyExc_TypeError, "comparison operator not supported for _ped.Constraint");
@@ -104,22 +98,26 @@ PyObject *_ped_Constraint_str(_ped_Constraint *self) {
     char *start_align = NULL, *end_align = NULL;
     char *start_range = NULL, *end_range = NULL;
 
-    start_align = PyString_AsString(_ped_Alignment_Type_obj.tp_repr(self->start_align));
+    start_align =
+PyUnicode_AsUTF8(_ped_Alignment_Type_obj.tp_repr(self->start_align));
     if (start_align == NULL) {
         return NULL;
     }
 
-    end_align = PyString_AsString(_ped_Alignment_Type_obj.tp_repr(self->end_align));
+    end_align =
+PyUnicode_AsUTF8(_ped_Alignment_Type_obj.tp_repr(self->end_align));
     if (end_align == NULL) {
         return NULL;
     }
 
-    start_range = PyString_AsString(_ped_Geometry_Type_obj.tp_repr(self->start_range));
+    start_range =
+PyUnicode_AsUTF8(_ped_Geometry_Type_obj.tp_repr(self->start_range));
     if (start_range == NULL) {
         return NULL;
     }
 
-    end_range = PyString_AsString(_ped_Geometry_Type_obj.tp_repr(self->end_range));
+    end_range =
+PyUnicode_AsUTF8(_ped_Geometry_Type_obj.tp_repr(self->end_range));
     if (end_range == NULL) {
         return NULL;
     }
@@ -266,9 +264,9 @@ PyObject *_ped_Constraint_get(_ped_Constraint *self, void *closure) {
     }
 
     if (!strcmp(member, "min_size")) {
-        return PyLong_FromLongLong(self->min_size);
+        return PyLong_FromLong(self->min_size);
     } else if (!strcmp(member, "max_size")) {
-        return PyLong_FromLongLong(self->max_size);
+        return PyLong_FromLong(self->max_size);
     } else {
         PyErr_Format(PyExc_AttributeError, "_ped.Constraint object has no attribute %s", member);
         return NULL;
@@ -284,12 +282,12 @@ int _ped_Constraint_set(_ped_Constraint *self, PyObject *value, void *closure) {
     }
 
     if (!strcmp(member, "min_size")) {
-        self->min_size = PyLong_AsLongLong(value);
+        self->min_size = PyLong_AsLong(value);
         if (PyErr_Occurred()) {
             return -1;
         }
     } else if (!strcmp(member, "max_size")) {
-        self->max_size = PyLong_AsLongLong(value);
+        self->max_size = PyLong_AsLong(value);
         if (PyErr_Occurred()) {
             return -1;
         }
