@@ -1,7 +1,7 @@
 /*
  * pydevice.c
  *
- * Copyright (C) 2007, 2008, 2009  Red Hat, Inc.
+ * Copyright (C) 2007-2013 Red Hat, Inc.
  *
  * This copyrighted material is made available to anyone wishing to use,
  * modify, copy, or redistribute it subject to the terms and conditions of
@@ -17,8 +17,9 @@
  * License and may only be used or replicated with the express permission of
  * Red Hat, Inc.
  *
- * Red Hat Author(s): David Cantrell <dcantrell@redhat.com>
- *                    Chris Lumens <clumens@redhat.com>
+ * Author(s): David Cantrell <dcantrell@redhat.com>
+ *            Chris Lumens <clumens@redhat.com>
+ *            Alex Skinner <alex@lx.lc>
  */
 
 #include <Python.h>
@@ -61,18 +62,11 @@ int _ped_CHSGeometry_compare(_ped_CHSGeometry *self, PyObject *obj) {
 
 PyObject *_ped_CHSGeometry_richcompare(_ped_CHSGeometry *a, PyObject *b,
                                        int op) {
-    if (op == Py_EQ) {
-        if (!(_ped_CHSGeometry_Type_obj.tp_compare((PyObject *) a, b))) {
-            Py_RETURN_TRUE;
-        } else {
-            Py_RETURN_FALSE;
-        }
-    } else if (op == Py_NE) {
-        if (_ped_CHSGeometry_Type_obj.tp_compare((PyObject *) a, b)) {
-            Py_RETURN_TRUE;
-        } else {
-            Py_RETURN_FALSE;
-        }
+    if (op == Py_EQ || op == Py_NE) {
+        int rv = _ped_CHSGeometry_compare(a, b);
+        if (PyErr_Occurred())
+            return NULL;
+        return PyBool_FromLong(op == Py_EQ ? rv == 0 : rv != 0);
     } else if ((op == Py_LT) || (op == Py_LE) ||
                (op == Py_GT) || (op == Py_GE)) {
         PyErr_SetString(PyExc_TypeError, "comparison operator not supported for _ped.CHSGeometry");
@@ -175,18 +169,11 @@ int _ped_Device_compare(_ped_Device *self, PyObject *obj) {
 }
 
 PyObject *_ped_Device_richcompare(_ped_Device *a, PyObject *b, int op) {
-    if (op == Py_EQ) {
-        if (!(_ped_Device_Type_obj.tp_compare((PyObject *) a, b))) {
-            Py_RETURN_TRUE;
-        } else {
-            Py_RETURN_FALSE;
-        }
-    } else if (op == Py_NE) {
-        if (_ped_Device_Type_obj.tp_compare((PyObject *) a, b)) {
-            Py_RETURN_TRUE;
-        } else {
-            Py_RETURN_FALSE;
-        }
+    if (op == Py_EQ || op == Py_NE) {
+        int rv = _ped_Device_compare(a, b);
+        if (PyErr_Occurred())
+            return NULL;
+        return PyBool_FromLong(op == Py_EQ ? rv == 0 : rv != 0);
     } else if ((op == Py_LT) || (op == Py_LE) ||
                (op == Py_GT) || (op == Py_GE)) {
         PyErr_SetString(PyExc_TypeError, "comparison operator not supported for _ped.Device");
@@ -201,12 +188,12 @@ PyObject *_ped_Device_str(_ped_Device *self) {
     char *ret = NULL;
     char *hw_geom = NULL, *bios_geom = NULL;
 
-    hw_geom = PyString_AsString(_ped_CHSGeometry_Type_obj.tp_repr(self->hw_geom));
+    hw_geom = PyUnicode_AsUTF8(_ped_CHSGeometry_Type_obj.tp_repr(self->hw_geom));
     if (hw_geom == NULL) {
         return NULL;
     }
 
-    bios_geom = PyString_AsString(_ped_CHSGeometry_Type_obj.tp_repr(self->bios_geom));
+    bios_geom = PyUnicode_AsUTF8(_ped_CHSGeometry_Type_obj.tp_repr(self->bios_geom));
     if (bios_geom == NULL) {
         return NULL;
     }
@@ -268,22 +255,22 @@ PyObject *_ped_Device_get(_ped_Device *self, void *closure) {
 
     if (!strcmp(member, "model")) {
         if (self->model != NULL)
-            return PyString_FromString(self->model);
+            return PyUnicode_FromString(self->model);
         else
-            return PyString_FromString("");
+            return PyUnicode_FromString("");
     } else if (!strcmp(member, "path")) {
         if (self->path != NULL)
-            return PyString_FromString(self->path);
+            return PyUnicode_FromString(self->path);
         else
-            return PyString_FromString("");
+            return PyUnicode_FromString("");
     } else if (!strcmp(member, "type")) {
-        return PyLong_FromLongLong(self->type);
+        return PyLong_FromLong(self->type);
     } else if (!strcmp(member, "sector_size")) {
-        return PyLong_FromLongLong(self->sector_size);
+        return PyLong_FromLong(self->sector_size);
     } else if (!strcmp(member, "phys_sector_size")) {
-        return PyLong_FromLongLong(self->phys_sector_size);
+        return PyLong_FromLong(self->phys_sector_size);
     } else if (!strcmp(member, "length")) {
-        return PyLong_FromLongLong(self->length);
+        return PyLong_FromLong(self->length);
     } else if (!strcmp(member, "open_count")) {
         return Py_BuildValue("i", self->open_count);
     } else if (!strcmp(member, "read_only")) {
@@ -366,7 +353,16 @@ PyObject *py_ped_device_get(PyObject *s, PyObject *args) {
         ret = PedDevice2_ped_Device(device);
     }
     else {
-        PyErr_Format(DeviceException, "Could not find device for path %s", path);
+        if (partedExnRaised) {
+            partedExnRaised = 0;
+
+            if (!PyErr_ExceptionMatches(PartedException) &&
+                !PyErr_ExceptionMatches(PyExc_NotImplementedError))
+                PyErr_SetString(IOException, partedExnMessage);
+        }
+        else
+            PyErr_Format(DeviceException, "Could not find device for path %s", path);
+
         return NULL;
     }
 
@@ -499,15 +495,8 @@ PyObject *py_ped_device_close(PyObject *s, PyObject *args) {
     }
 }
 
-/*
- * XXX: the reason we want to call ped_device_destroy() here is
- * to unregister the device.  We need to figure out how to also
- * get a 'del' operation run on the _ped.Device itself.
- *
- * Possible solution could be to put a call to ped_device_destroy()
- * in the tp_clear function to make sure it gets unregistered.
- */
 PyObject *py_ped_device_destroy(PyObject *s, PyObject *args) {
+    _ped_Device *dev = (_ped_Device *) s;
     PedDevice *device = NULL;
 
     device = _ped_Device2PedDevice(s);
@@ -516,7 +505,14 @@ PyObject *py_ped_device_destroy(PyObject *s, PyObject *args) {
     }
 
     ped_device_destroy(device);
-    Py_CLEAR(s);
+
+    Py_CLEAR(dev->hw_geom);
+    dev->hw_geom = NULL;
+
+    Py_CLEAR(dev->bios_geom);
+    dev->bios_geom = NULL;
+
+    Py_CLEAR(dev);
 
     Py_INCREF(Py_None);
     return Py_None;
@@ -656,7 +652,7 @@ PyObject *py_ped_device_read(PyObject *s, PyObject *args) {
         return NULL;
     }
 
-    ret = PyString_FromString(out_buf);
+    ret = PyUnicode_FromString(out_buf);
     free(out_buf);
 
     return ret;
@@ -677,7 +673,7 @@ PyObject *py_ped_device_write(PyObject *s, PyObject *args) {
         return NULL;
     }
 
-    out_buf = PyCObject_AsVoidPtr(in_buf);
+    out_buf = PyCapsule_GetPointer(in_buf, 0);
     if (out_buf == NULL) {
         return NULL;
     }
@@ -707,7 +703,7 @@ PyObject *py_ped_device_write(PyObject *s, PyObject *args) {
         return NULL;
     }
 
-    return PyLong_FromLongLong(ret);
+    return PyLong_FromLong(ret);
 }
 
 PyObject *py_ped_device_sync(PyObject *s, PyObject *args) {
@@ -823,7 +819,7 @@ PyObject *py_ped_device_check(PyObject *s, PyObject *args) {
     ret = ped_device_check(device, out_buf, start, count);
     free(out_buf);
 
-    return PyLong_FromLongLong(ret);
+    return PyLong_FromLong(ret);
 }
 
 PyObject *py_ped_device_get_constraint(PyObject *s, PyObject *args) {
@@ -850,5 +846,93 @@ PyObject *py_ped_device_get_constraint(PyObject *s, PyObject *args) {
     return (PyObject *) ret;
 }
 
+PyObject *py_ped_device_get_minimal_aligned_constraint(PyObject *s, PyObject *args) {
+    PedDevice *device = NULL;
+    PedConstraint *constraint = NULL;
+    _ped_Constraint *ret = NULL;
+
+    device = _ped_Device2PedDevice(s);
+    if (device == NULL) {
+        return NULL;
+    }
+
+    constraint = ped_device_get_minimal_aligned_constraint(device);
+    if (!constraint) {
+        PyErr_SetString(CreateException, "Could not create constraint");
+        return NULL;
+    }
+
+    ret = PedConstraint2_ped_Constraint(constraint);
+    ped_constraint_destroy(constraint);
+
+    return (PyObject *) ret;
+}
+
+PyObject *py_ped_device_get_optimal_aligned_constraint(PyObject *s, PyObject *args) {
+    PedDevice *device = NULL;
+    PedConstraint *constraint = NULL;
+    _ped_Constraint *ret = NULL;
+
+    device = _ped_Device2PedDevice(s);
+    if (device == NULL) {
+        return NULL;
+    }
+
+    constraint = ped_device_get_optimal_aligned_constraint(device);
+    if (!constraint) {
+        PyErr_SetString(CreateException, "Could not create constraint");
+        return NULL;
+    }
+
+    ret = PedConstraint2_ped_Constraint(constraint);
+    ped_constraint_destroy(constraint);
+
+    return (PyObject *) ret;
+}
+
+PyObject *py_ped_device_get_minimum_alignment(PyObject *s, PyObject *args) {
+    PedDevice *device = NULL;
+    PedAlignment *alignment = NULL;
+    _ped_Alignment *ret = NULL;
+
+    device = _ped_Device2PedDevice(s);
+    if (device == NULL) {
+        return NULL;
+    }
+
+    alignment = ped_device_get_minimum_alignment(device);
+    if (!alignment) {
+        PyErr_SetString(CreateException, "Could not get alignment for device");
+        return NULL;
+    }
+
+    ret = PedAlignment2_ped_Alignment(alignment);
+    ped_alignment_destroy(alignment);
+
+    return (PyObject *) ret;
+}
+
+PyObject *py_ped_device_get_optimum_alignment(PyObject *s, PyObject *args) {
+    PedDevice *device = NULL;
+    PedAlignment *alignment = NULL;
+    _ped_Alignment *ret = NULL;
+
+    device = _ped_Device2PedDevice(s);
+    if (device == NULL) {
+        return NULL;
+    }
+
+    alignment = ped_device_get_optimum_alignment(device);
+    if (!alignment) {
+        PyErr_SetString(CreateException, "Could not get alignment for device");
+        return NULL;
+    }
+
+    ret = PedAlignment2_ped_Alignment(alignment);
+    ped_alignment_destroy(alignment);
+
+    return (PyObject *) ret;
+}
+
 /* vim:tw=78:ts=4:et:sw=4
  */
